@@ -18,7 +18,7 @@ class Radio():
   def __init__(self, origin_path, max_depth=MAX_DEPTH):
     self.origin_path = os.path.abspath(origin_path)
     self.max_depth = max_depth
-    self.resolved_path = None
+    self.relay_path = None
   
   def __enter__(self):
     '''scan ancestor directories up to a certain depth for the first relay file and add that directory to the module import context'''
@@ -30,14 +30,14 @@ class Radio():
       relay_file_path = os.path.join(curr_path, RELAY_FILENAME)
       if os.path.exists(relay_file_path):
         log.info(f'depth of {depth} reached - .relay file found in {curr_path} - adding to module import context...')
-        self.resolved_path = curr_path
-        if self.resolved_path not in sys.path:
-          sys.path.append(self.resolved_path)
+        self.relay_path = curr_path
+        if self.relay_path not in sys.path:
+          sys.path.append(self.relay_path)
         break
       else:
         log.info(f'depth of {depth} reached - .relay file not found in {curr_path} - checking next parent...')
 
-    if not self.resolved_path:    
+    if not self.relay_path:    
       log.warning(f'max depth of {depth} reached - .relay file not found in any ancestor paths - no changes were made to module import context.')
     
     return self
@@ -45,6 +45,6 @@ class Radio():
   def __exit__(self, type, value, traceback):
     '''remove relayed directory from the module import context'''
 
-    if self.resolved_path:
-      log.debug(f'finished relaying {self.resolved_path} to {self.origin_path} - removing from module import context...')
-      sys.path.remove(self.resolved_path)
\ No newline at end of file
+    if self.relay_path:
+      log.debug(f'finished relaying {self.relay_path} to {self.origin_path} - removing from module import context...')
+      sys.path.remove(self.relay_path)
\ No newline at end of file
